// LDA_ANALYSIS_2.1
// created: 10-29-2009
// author:  RF
// last modification: 10-29-2009 



// contents:
// 01. lda_open_write_file_output_1
// 02. lda_open_write_file_output_stat_raw
// 03. lda_open_write_file_output_stat_resamp
// 04. lda_open_write_file_output_tecplot_raw
// 05. lda_open_write_file_output_tecplot_resamp
// 06. lda_open_write_file_output_profit_raw
// 07. lda_open_write_file_output_profit_resamp
// 08. lda_open_write_file_output_autocorrelation






/******************************************************
* function    : lda_output_post_processed_timeseries  *
*-----------------------------------------------------*
* task        : open one file for ASCII-output:       *
*               one timeseries                        *
* parameter   : no one                                *
* return value: no one                                *
******************************************************/
void lda_open_write_file_output_ts()
{
    if (raw_filename_output == 0) {
        sprintf(lda_ts_outputfile, "TS\\%s_%s_%s_%s_%s%s_%s_%s_%s_%s_EWTL.ts",
                str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1, str_comp2, str_instnumb,
                str_winddir, meas_number_string, ts_string);
    }
    if (raw_filename_output == 1) {
        sprintf(lda_ts_outputfile, "TS\\%s_%s_EWTL.ts", meas_code, ts_string);
    }        
    fh = fopen(lda_ts_outputfile, "w");



        fprintf(fh, "# EWTL post-processed LDA time series\n");
        fprintf(fh, "# \n");
        fprintf(fh, "# ********** DATA DESCRIPTION **********\n");
        fprintf(fh, "# \n# \n# \n# \n# \n");
        fprintf(fh, "# ********** GENERAL INFORMATION **********\n");
        fprintf(fh, "# %s [main project name]\n", str_maincamp);
        fprintf(fh, "# %s [sub project name]\n", str_subcamp);
        if (strcmp(str_wt, BLASIUS) == 0) {
            fprintf(fh, "# BLASIUS [wind tunnel facility]\n");
        }
        else if (strcmp(str_wt, WOTAN) == 0) {
            fprintf(fh, "# WOTAN [wind tunnel facility]\n");
        }
        fprintf(fh, "# 1:%i [model - scale]\n", model_scale);
        fprintf(fh, "# %5.2lf [zref - full scale [m]]\n", ref_height*model_scale);
        fprintf(fh, "# %5.2lf [zref - model scale [mm]]\n", ref_height*1000.);
        fprintf(fh, "# %5.2lf [Uref - model [m/s]]\n", u_ref*lda_scale_factor);
        fprintf(fh, "# %5.2lf [approach flow direction []]\n", atoi(str_winddir)/10.);
        fprintf(fh, "# 1.0 [Lref - model scale [m]]\n");
        fprintf(fh, "# %i [Lref - full scale [m]]\n", model_scale);
        fprintf(fh, "# # [utm zone]\n");

        if(quality_flag == 0) { 
            fprintf(fh, "# \n# \n# \n# \n# \n# \n# \n# \n# \n# \n");
        }
        if(quality_flag == 1) {
            fprintf(fh, "# \n# ATTENTION: in case of an approach flow measurement,\n");
            fprintf(fh, "#            timeseries is not adequate for boundary layer characterization!\n");
            fprintf(fh, "#            (position below 1.5 height of roughness elements)\n");
            fprintf(fh, "# \n# \n# \n# \n# \n# \n");
        }
        if(quality_flag == 2) {
            fprintf(fh, "# \n# ATTENTION: handle with care,\n");
            fprintf(fh, "#            flow might be out of the prandtl layer!\n");
            fprintf(fh, "#            (position within ]100 m; 150 m] height in full scale)\n");
            fprintf(fh, "# \n# \n# \n# \n# \n# \n");
        }
        if(quality_flag == 3) {
            fprintf(fh, "# \n# ATTENTION: flow is out of the model area (prandtl layer)!\n");
            fprintf(fh, "#            (position above 150 m height in full scale)\n");
            fprintf(fh, "# \n# \n# \n# \n# \n# \n# \n");
        }
        
        fprintf(fh, "# ********** FLOW MEASUREMENTS **********\n");
        fprintf(fh, "# %s (%s)[measurement type]\n", str_meastype, str_insttype);
        fprintf(fh, "# 5 [number of columns]\n");
        fprintf(fh, "# \"I\" \"T*\" \"U/Uref\" \"V/Uref\" \"W/Uref\" [labels]\n");
        fprintf(fh, "# %s%s [measured components]\n", str_comp1, str_comp2);
        fprintf(fh, "# %5.2lf [measurement location X - model scale [mm]]\n", atof(x_position));  
        fprintf(fh, "# %5.2lf [measurement location Y - model scale [mm]]\n", atof(y_position));  
        fprintf(fh, "# %5.2lf [measurement location Z - model scale [mm]]\n", atof(z_position));  
        fprintf(fh, "# %5.2lf [measurement location X - full scale [m]]\n", (atof(x_position)/1000.)*model_scale);  
        fprintf(fh, "# %5.2lf [measurement location Y - full scale [m]]\n", (atof(y_position)/1000.)*model_scale);  
        fprintf(fh, "# %5.2lf [measurement location Z - full scale [m]]\n", (atof(z_position)/1000.)*model_scale);
        fprintf(fh, "# # [measurement location utm Easting [m]]\n");
        fprintf(fh, "# # [measurement location utm Northing [m]]\n");
        if (strcmp(str_comp1, U_WIND) == 0 && strcmp(str_comp2, V_WIND) == 0) {   
            fprintf(fh, "# %5.3lf %5.3lf [confidence intervall {U,V}/Uref[-]]\n", reproducibility_comp1, reproducibility_comp2);
        }
        if (strcmp(str_comp1, U_WIND) == 0 && strcmp(str_comp2, W_WIND) == 0) {   
            fprintf(fh, "# %5.3lf %5.3lf [confidence intervall {U,W}/Uref[-]]\n", reproducibility_comp1, reproducibility_comp2);
        }
        if (strcmp(str_comp1, V_WIND) == 0 && strcmp(str_comp2, W_WIND) == 0) {   
            fprintf(fh, "# %5.3lf %5.3lf [confidence intervall {V,W}/Uref[-]]\n", reproducibility_comp1, reproducibility_comp2);
        }
        fprintf(fh, "# \n# \n# \n# \n# \n# \n# \n# \n# \n# \n");

        fprintf(fh, "# ********** CONCENTRATION MEASUREMENTS **********\n");
        fprintf(fh, "# # [measurement type]\n");
        fprintf(fh, "# # [number of columns]\n");
        fprintf(fh, "# # [labels]\n");
        fprintf(fh, "# # [released gas]\n");
        fprintf(fh, "# # [source strength [l/h]]\n");
        fprintf(fh, "# # [release duration [s]]\n");
        fprintf(fh, "# # [number of released puffs]\n");
        fprintf(fh, "# # [number of detected puffs, which dosage exceeds the dosage threshold]\n");
        fprintf(fh, "# # [discard threshold/minimum dosage - model scale [ppmvs] ]\n");
        fprintf(fh, "# # [source location X - model scale [mm]]\n");
        fprintf(fh, "# # [source location Y - model scale [mm]]\n");
        fprintf(fh, "# # [source location Z - model scale [mm]]\n");
        fprintf(fh, "# # [source location X - full scale [m]]\n");
        fprintf(fh, "# # [source location Y - full scale [m]]\n");
        fprintf(fh, "# # [source location Z - full scale [m]]\n");
        fprintf(fh, "# # [source location utm Easting [m]]\n");
        fprintf(fh, "# # [source location utm Northing [m]]\n");
        fprintf(fh, "# # [measurement location X - model scale [mm]]\n");
        fprintf(fh, "# # [measurement location Y - model scale [mm]]\n");
        fprintf(fh, "# # [measurement location Z - model scale [mm]]\n");
        fprintf(fh, "# # [measurement location X - full scale [m]]\n");
        fprintf(fh, "# # [measurement location Y - full scale [m]]\n");
        fprintf(fh, "# # [measurement location Z - full scale [m]]\n");
        fprintf(fh, "# # [measurement location utm Easting [m]]\n");
        fprintf(fh, "# # [measurement location utm Northing [m]]\n");
        fprintf(fh, "# # [1E-6 * confidence intervall [-]]\n");

        fprintf(fh, "# \n# \n# \n# \n# \n# \n# \n# \n");

        fprintf(fh, "# %s [date of measurement]\n", time_stamp);
        fprintf(fh, "# ********** END OF HEADER **********\n");




    if (strcmp(str_comp1, U_WIND) == 0 && strcmp(str_comp2, W_WIND) == 0) {
        
        fprintf(fh, "VARIABLES= \"I [-]\" \"T<sup>*</sup> [-]\" \"%s/U<sub>ref</sub> [-]\" \"V/U<sub>ref</sub> [-]\" \"%s/U<sub>ref</sub> [-]\"\n", str_comp1, str_comp2);  
      
 
        i = 0;
    
        do {    

            fprintf(fh, "%i   %lf   %5.4lf   %6.3lf   %5.4lf\n", i, (u_ref*lda_scale_factor*data_raw[0][i])/1., (data_raw[2][i]/u_ref)/lda_scale_factor, DEFAULT_VALUE, (data_raw[3][i]/u_ref)/lda_scale_factor);
            i++;
        } while(i < data_count[0]);
    }



    if (strcmp(str_comp1, U_WIND) == 0 && strcmp(str_comp2, V_WIND) == 0) {
        
        fprintf(fh, "VARIABLES= \"I [-]\" \"T<sup>*</sup> [-]\" \"%s/U<sub>ref</sub> [-]\" \"%s/U<sub>ref</sub> [-]\" \"W/U<sub>ref</sub> [-]\"\n", str_comp1, str_comp2);  
      
 
        i = 0;
    
        do {    

            fprintf(fh, "%i   %lf   %5.4lf   %5.4lf   %6.3lf\n", i, (u_ref*lda_scale_factor*data_raw[0][i])/1., (data_raw[2][i]/u_ref)/lda_scale_factor, (data_raw[3][i]/u_ref)/lda_scale_factor, DEFAULT_VALUE);
            i++;
        } while(i < data_count[0]);
    }
    


    if (strcmp(str_comp1, V_WIND) == 0 && strcmp(str_comp2, W_WIND) == 0) {
        
        fprintf(fh, "VARIABLES= \"I [-]\" \"T<sup>*</sup> [-]\" \"U/U<sub>ref</sub> [-]\" \"%s/U<sub>ref</sub> [-]\" \"%s/U<sub>ref</sub> [-]\"\n", str_comp1, str_comp2);  
      
 
        i = 0;
    
        do {    

            fprintf(fh, "%i   %lf   %6.3lf   %5.4lf   %5.4lf\n", i, (u_ref*lda_scale_factor*data_raw[0][i])/1., DEFAULT_VALUE, (data_raw[2][i]/u_ref)/lda_scale_factor, (data_raw[3][i]/u_ref)/lda_scale_factor);
            i++;
        } while(i < data_count[0]);
    }


    fclose(fh);
}






/******************************************************
* function    : lda_output_statistic_file             *
*-----------------------------------------------------*
* task        : open one file for ASCII-output:       *
*               one statistic file                    *
* parameter   : no one                                *
* return value: no one                                *
******************************************************/
void lda_output_statistic_file()
{
    if (raw_filename_output == 0) {
        sprintf(out_file_statistics, "STAT\\%s_%s_%s_%s_%s%s_%s_%s_%s_EWTL.stat",
                str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1, str_comp2, str_instnumb,
                str_winddir, meas_number_string);
    }
    if (raw_filename_output == 1) {
        sprintf(out_file_statistics, "STAT\\%s_EWTL.stat", meas_code);
    }        
    fh = fopen(out_file_statistics, "a");


        if(lda_ts_index == 0){

            fprintf(fh, "# EWTL LDA time series statistics\n");
            fprintf(fh, "# \n");
            fprintf(fh, "# ********** DATA DESCRIPTION **********\n");
            fprintf(fh, "# \n# \n# \n# \n# \n");
            fprintf(fh, "# ********** GENERAL INFORMATION **********\n");
            fprintf(fh, "# %s [main project name]\n", str_maincamp);
            fprintf(fh, "# %s [sub project name]\n", str_subcamp);
            if (strcmp(str_wt, BLASIUS) == 0) {
                fprintf(fh, "# BLASIUS [wind tunnel facility]\n");
            }
            else if (strcmp(str_wt, WOTAN) == 0) {
                fprintf(fh, "# WOTAN [wind tunnel facility]\n");
            }
            fprintf(fh, "# 1:%i [model - scale]\n", model_scale);
            fprintf(fh, "# %5.2lf [zref - full scale [m]]\n", ref_height*model_scale);
            fprintf(fh, "# %5.2lf [zref - model scale [mm]]\n", ref_height*1000.);
            //fprintf(fh, "# %5.2lf [Uref - model [m/s]]\n", u_ref*lda_scale_factor);
            fprintf(fh, "# %5.2lf [wind direction []]\n", atoi(str_winddir)/10.);
            fprintf(fh, "# 1.0 [Lref - model scale [m]]\n");
            fprintf(fh, "# %i [Lref - full scale [m]]\n", model_scale);
            fprintf(fh, "# # [utm zone]\n");

            fprintf(fh, "# \n# \n# \n# \n# \n# \n# \n# \n# \n# \n");
        
            fprintf(fh, "# %s [date of measurement]\n", time_stamp);
            fprintf(fh, "# ********** END OF HEADER **********\n");
        }
        
        u_ref_sc = u_ref*lda_scale_factor;

        if (strcmp(str_comp1, U_WIND) == 0 && strcmp(str_comp2, V_WIND) == 0) {
            
            if(lda_ts_index == 0){
                
                fprintf(fh, "# \"number of time series\" \"number of samples\" \"data rate[Hz]\" \"Xfs[m]\" \"Yfs[m]\" \"Zfs[m]\" \"Xm[mm]\" \"Ym[mm]\" \"Zm[mm]\"\
 \"Uref[m/s]\" \"U/Uref[-]\" \"V/Uref[-]\" \"W/Uref[-]\" \"Urms/Uref[-]\" \"Vrms/Uref[-]\" \"Wrms/Uref[-]\" \"u'v'/Uref^2[-]\" \"u'w'/Uref^2[-]\"\
 \"v'w'/Uref^2[-]\" \"Uconf/Uref[-]\" \"Vconf/Uref[-]\" \"Wconf/Uref[-]\" \"U[m/s]\" \"V[m/s]\" \"W[m/s]\" \"Urms[m/s]\" \"Vrms[m/s]\" \"Wrms[m/s]\"\
 \"u'v'[m^2/s^2]\" \"u'w'[m^2/s^2]\" \"v'w'[m^2/s^2]\" \"Uconf[m/s]\" \"Vconf[m/s]\" \"Wconf[m/s]\" \"Uskewness\" \"Uflatness\" \"Vskewness\"\
 \"Vflatness\" \"Wskewness\" \"Wflatness\" \"Luxfs[m]\" \"Luxm[mm]\" \"C^*[-]\" \"C^*rms[-]\" \"C^*skewness\" \"C^*flatness\"\
 \"flag1\" \"flag2\" \"flag3\" \"quality flag\"\n# \n\
VARIABLES= \"number of time series\" \"number of samples\" \"data rate [Hz]\" \"X<sub>fs</sub> [m]\" \"Y<sub>fs</sub> [m]\"\
 \"Z<sub>fs</sub> [m]\" \"X<sub>m</sub> [mm]\" \"Y<sub>m</sub> [mm]\" \"Z<sub>m</sub> [mm]\" \"U<sub>ref</sub> [m/s]\" \"U<sub>mean</sub>/U<sub>ref</sub> [-]\"\
 \"V<sub>mean</sub>/U<sub>ref</sub> [-]\" \"W<sub>mean</sub>/U<sub>ref</sub> [-]\" \"U<sub>rms</sub>/U<sub>ref</sub> [-]\"\
 \"V<sub>rms</sub>/U<sub>ref</sub> [-]\" \"W<sub>rms</sub>/U<sub>ref</sub> [-]\" \"U'V'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\"\
 \"U'W'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\" \"V'W'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\"\
 \"U<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\" \"V<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\" \"W<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\"\
 \"U<sub>mean</sub> [m/s]\" \"V<sub>mean</sub> [m/s]\" \"W<sub>mean</sub> [m/s]\"\
 \"U<sub>rms</sub> [m/s]\" \"V<sub>rms</sub> [m/s]\" \"W<sub>rms</sub> [m/s]\" \"U'V'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\"\
 \"U'W'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\" \"V'W'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\" \"U<sub>mean-conf-%i%%</sub> [m/s]\"\
 \"V<sub>mean-conf-%i%%</sub> [m/s]\" \"W<sub>mean-conf-%i%%</sub> [m/s]\" \"U-skewness\"\
 \"U-flatness\" \"V-skewness\" \"V-flatness\" \"W-skewness\" \"W-flatness\" \"L<sub>uxfs</sub> [m]\" \"L<sub>uxm</sub> [mm]\"\
 \"C<sup>*</sup> [-]\" \"C<sup>*</sup><sub>rms</sub> [-]\" \"C<sup>*</sup><sub>skewness</sub>\" \"C<sup>*</sup><sub>flatness</sub>\"\
 \"data flag 1\" \"data flag 2\" \"data flag 3\" \"quality flag\"\n", (int)confidence_interval, (int)confidence_interval, (int)confidence_interval,
 (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval,
 (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval);
                fprintf(fh, "ZONE T = \"%s_%s_%s_%s_%s_%s_%s_%s_%s\"\n",
                        str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1, str_comp2, str_instnumb, str_winddir, meas_number_string);
            }

            fprintf(fh, "%i   %i   %6.0lf   %6.3lf   %6.3lf   %6.3lf   %6.1lf   %6.1lf   %6.1lf   %6.2lf   %6.4lf   %6.4lf   %6.3lf   %6.4lf   %6.4lf   %6.3lf\
   %6.8lf   %6.3lf   %6.3lf   %6.4lf   %6.4lf   %6.3lf   %6.2lf   %6.2lf   %6.3lf   %6.2lf   %6.2lf\
   %6.3lf   %6.4lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf\
   %6.3lf   %6.3lf   %6.1lf   %6.1lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %i\n",
                    lda_ts_startnumber + lda_ts_index, data_count[0],
                    data_rate_mean,
                    model_scale*atof(x_position)/1000., model_scale*atof(y_position)/1000., model_scale*atof(z_position)/1000.,
                    atof(x_position), atof(y_position), atof(z_position), u_ref*lda_scale_factor,
                    data_raw_comp1_mean_arith/u_ref_sc, data_raw_comp2_mean_arith/u_ref_sc, DEFAULT_VALUE,
                    data_raw_comp1_rms_arith/u_ref_sc, data_raw_comp2_rms_arith/u_ref_sc, DEFAULT_VALUE,
                    data_raw_comp12_covar_arith/pow(u_ref_sc, 2.), DEFAULT_VALUE, DEFAULT_VALUE,
                    data_raw_comp1_mean_conf_arith/u_ref_sc, data_raw_comp2_mean_conf_arith/u_ref_sc, DEFAULT_VALUE,
                    data_raw_comp1_mean_arith, data_raw_comp2_mean_arith, DEFAULT_VALUE,
                    data_raw_comp1_rms_arith, data_raw_comp2_rms_arith, DEFAULT_VALUE,
                    data_raw_comp12_covar_arith, DEFAULT_VALUE, DEFAULT_VALUE,
                    data_raw_comp1_mean_conf_arith, data_raw_comp2_mean_conf_arith, DEFAULT_VALUE,
                    data_raw_comp1_skew_arith, data_raw_comp1_flat_arith,
                    data_raw_comp2_skew_arith, data_raw_comp2_flat_arith,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    l_ux*model_scale, l_ux*1000.,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, quality_flag);
        }




        if (strcmp(str_comp1, U_WIND) == 0 && strcmp(str_comp2, W_WIND) == 0) {
            
            if(lda_ts_index == 0){
                
                fprintf(fh, "# \"number of time series\" \"number of samples\" \"data rate[Hz]\" \"Xfs[m]\" \"Yfs[m]\" \"Zfs[m]\" \"Xm[mm]\" \"Ym[mm]\" \"Zm[mm]\"\
 \"Uref[m/s]\" \"U/Uref[-]\" \"V/Uref[-]\" \"W/Uref[-]\" \"Urms/Uref[-]\" \"Vrms/Uref[-]\" \"Wrms/Uref[-]\" \"u'v'/Uref^2[-]\" \"u'w'/Uref^2[-]\"\
 \"v'w'/Uref^2[-]\" \"Uconf/Uref[-]\" \"Vconf/Uref[-]\" \"Wconf/Uref[-]\" \"U[m/s]\" \"V[m/s]\" \"W[m/s]\" \"Urms[m/s]\" \"Vrms[m/s]\" \"Wrms[m/s]\"\
 \"u'v'[m^2/s^2]\" \"u'w'[m^2/s^2]\" \"v'w'[m^2/s^2]\" \"Uconf[m/s]\" \"Vconf[m/s]\" \"Wconf[m/s]\" \"Uskewness\" \"Uflatness\" \"Vskewness\"\
 \"Vflatness\" \"Wskewness\" \"Wflatness\" \"Luxfs[m]\" \"Luxm[mm]\" \"C^*[-]\" \"C^*rms[-]\" \"C^*skewness\" \"C^*flatness\"\
 \"flag1\" \"flag2\" \"flag3\" \"quality flag\"\n# \n\
VARIABLES= \"number of time series\" \"number of samples\" \"data rate [Hz]\" \"X<sub>fs</sub> [m]\" \"Y<sub>fs</sub> [m]\"\
 \"Z<sub>fs</sub> [m]\" \"X<sub>m</sub> [mm]\" \"Y<sub>m</sub> [mm]\" \"Z<sub>m</sub> [mm]\" \"U<sub>ref</sub> [m/s]\" \"U<sub>mean</sub>/U<sub>ref</sub> [-]\"\
 \"V<sub>mean</sub>/U<sub>ref</sub> [-]\" \"W<sub>mean</sub>/U<sub>ref</sub> [-]\" \"U<sub>rms</sub>/U<sub>ref</sub> [-]\"\
 \"V<sub>rms</sub>/U<sub>ref</sub> [-]\" \"W<sub>rms</sub>/U<sub>ref</sub> [-]\" \"U'V'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\"\
 \"U'W'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\" \"V'W'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\"\
 \"U<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\" \"V<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\" \"W<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\"\
 \"U<sub>mean</sub> [m/s]\" \"V<sub>mean</sub> [m/s]\" \"W<sub>mean</sub> [m/s]\"\
 \"U<sub>rms</sub> [m/s]\" \"V<sub>rms</sub> [m/s]\" \"W<sub>rms</sub> [m/s]\" \"U'V'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\"\
 \"U'W'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\" \"V'W'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\" \"U<sub>mean-conf-%i%%</sub> [m/s]\"\
 \"V<sub>mean-conf-%i%%</sub> [m/s]\" \"W<sub>mean-conf-%i%%</sub> [m/s]\" \"U-skewness\"\
 \"U-flatness\" \"V-skewness\" \"V-flatness\" \"W-skewness\" \"W-flatness\" \"L<sub>uxfs</sub> [m]\" \"L<sub>uxm</sub> [mm]\"\
 \"C<sup>*</sup> [-]\" \"C<sup>*</sup><sub>rms</sub> [-]\" \"C<sup>*</sup><sub>skewness</sub>\" \"C<sup>*</sup><sub>flatness</sub>\"\
 \"data flag 1\" \"data flag 2\" \"data flag 3\" \"quality flag\"\n", (int)confidence_interval, (int)confidence_interval, (int)confidence_interval,
 (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval,
 (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval);
                fprintf(fh, "ZONE T = \"%s_%s_%s_%s_%s_%s_%s_%s_%s\"\n",
                        str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1, str_comp2, str_instnumb, str_winddir, meas_number_string);
            }

            fprintf(fh, "%i   %i   %6.0lf   %6.3lf   %6.3lf   %6.3lf   %6.1lf   %6.1lf   %6.1lf   %6.2lf   %6.4lf   %6.3lf   %6.4lf   %6.4lf   %6.3lf   %6.4lf\
   %6.3lf   %6.8lf   %6.3lf   %6.4lf   %6.3lf   %6.4lf   %6.2lf   %6.3lf   %6.2lf   %6.2lf   %6.3lf\
   %6.2lf   %6.3lf   %6.4lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf\
   %6.3lf   %6.3lf   %6.1lf   %6.1lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %i\n",
                    lda_ts_startnumber + lda_ts_index, data_count[0],
                    data_rate_mean,
                    model_scale*atof(x_position)/1000., model_scale*atof(y_position)/1000., model_scale*atof(z_position)/1000.,
                    atof(x_position), atof(y_position), atof(z_position), u_ref*lda_scale_factor,
                    data_raw_comp1_mean_arith/u_ref_sc, DEFAULT_VALUE, data_raw_comp2_mean_arith/u_ref_sc,
                    data_raw_comp1_rms_arith/u_ref_sc, DEFAULT_VALUE, data_raw_comp2_rms_arith/u_ref_sc,
                    DEFAULT_VALUE, data_raw_comp12_covar_arith/pow(u_ref_sc, 2.), DEFAULT_VALUE,
                    data_raw_comp1_mean_conf_arith/u_ref_sc, DEFAULT_VALUE, data_raw_comp2_mean_conf_arith/u_ref_sc,
                    data_raw_comp1_mean_arith, DEFAULT_VALUE, data_raw_comp2_mean_arith,
                    data_raw_comp1_rms_arith, DEFAULT_VALUE, data_raw_comp2_rms_arith,
                    DEFAULT_VALUE, data_raw_comp12_covar_arith, DEFAULT_VALUE,
                    data_raw_comp1_mean_conf_arith, DEFAULT_VALUE, data_raw_comp2_mean_conf_arith,
                    data_raw_comp1_skew_arith, data_raw_comp1_flat_arith,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    data_raw_comp2_skew_arith, data_raw_comp2_flat_arith,
                    l_ux*model_scale, l_ux*1000.,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, quality_flag);
        }




        if (strcmp(str_comp1, V_WIND) == 0 && strcmp(str_comp2, W_WIND) == 0) {
            
            if(lda_ts_index == 0){
                
                fprintf(fh, "# \"number of time series\" \"number of samples\" \"data rate[Hz]\" \"Xfs[m]\" \"Yfs[m]\" \"Zfs[m]\" \"Xm[mm]\" \"Ym[mm]\" \"Zm[mm]\"\
 \"Uref[m/s]\" \"U/Uref[-]\" \"V/Uref[-]\" \"W/Uref[-]\" \"Urms/Uref[-]\" \"Vrms/Uref[-]\" \"Wrms/Uref[-]\" \"u'v'/Uref^2[-]\" \"u'w'/Uref^2[-]\"\
 \"v'w'/Uref^2[-]\" \"Uconf/Uref[-]\" \"Vconf/Uref[-]\" \"Wconf/Uref[-]\" \"U[m/s]\" \"V[m/s]\" \"W[m/s]\" \"Urms[m/s]\" \"Vrms[m/s]\" \"Wrms[m/s]\"\
 \"u'v'[m^2/s^2]\" \"u'w'[m^2/s^2]\" \"v'w'[m^2/s^2]\" \"Uconf[m/s]\" \"Vconf[m/s]\" \"Wconf[m/s]\" \"Uskewness\" \"Uflatness\" \"Vskewness\"\
 \"Vflatness\" \"Wskewness\" \"Wflatness\" \"Luxfs[m]\" \"Luxm[mm]\" \"C^*[-]\" \"C^*rms[-]\" \"C^*skewness\" \"C^*flatness\"\
 \"flag1\" \"flag2\" \"flag3\" \"quality flag\"\n# \n\
VARIABLES= \"number of time series\" \"number of samples\" \"data rate [Hz]\" \"X<sub>fs</sub> [m]\" \"Y<sub>fs</sub> [m]\"\
 \"Z<sub>fs</sub> [m]\" \"X<sub>m</sub> [mm]\" \"Y<sub>m</sub> [mm]\" \"Z<sub>m</sub> [mm]\" \"U<sub>ref</sub> [m/s]\" \"U<sub>mean</sub>/U<sub>ref</sub> [-]\"\
 \"V<sub>mean</sub>/U<sub>ref</sub> [-]\" \"W<sub>mean</sub>/U<sub>ref</sub> [-]\" \"U<sub>rms</sub>/U<sub>ref</sub> [-]\"\
 \"V<sub>rms</sub>/U<sub>ref</sub> [-]\" \"W<sub>rms</sub>/U<sub>ref</sub> [-]\" \"U'V'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\"\
 \"U'W'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\" \"V'W'<sub>mean</sub>/U<sub>ref</sub><sup>2</sup> [-]\"\
 \"U<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\" \"V<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\" \"W<sub>mean-conf-%i%%</sub>/U<sub>ref</sub> [-]\"\
 \"U<sub>mean</sub> [m/s]\" \"V<sub>mean</sub> [m/s]\" \"W<sub>mean</sub> [m/s]\"\
 \"U<sub>rms</sub> [m/s]\" \"V<sub>rms</sub> [m/s]\" \"W<sub>rms</sub> [m/s]\" \"U'V'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\"\
 \"U'W'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\" \"V'W'<sub>mean</sub> [m<sup>2</sup>/s<sup>2</sup>]\" \"U<sub>mean-conf-%i%%</sub> [m/s]\"\
 \"V<sub>mean-conf-%i%%</sub> [m/s]\" \"W<sub>mean-conf-%i%%</sub> [m/s]\" \"U-skewness\"\
 \"U-flatness\" \"V-skewness\" \"V-flatness\" \"W-skewness\" \"W-flatness\" \"L<sub>uxfs</sub> [m]\" \"L<sub>uxm</sub> [mm]\"\
 \"C<sup>*</sup> [-]\" \"C<sup>*</sup><sub>rms</sub> [-]\" \"C<sup>*</sup><sub>skewness</sub>\" \"C<sup>*</sup><sub>flatness</sub>\"\
 \"data flag 1\" \"data flag 2\" \"data flag 3\" \"quality flag\"\n", (int)confidence_interval, (int)confidence_interval, (int)confidence_interval,
 (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval,
 (int)confidence_interval, (int)confidence_interval, (int)confidence_interval, (int)confidence_interval);
                fprintf(fh, "ZONE T = \"%s_%s_%s_%s_%s_%s_%s_%s_%s\"\n",
                        str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1, str_comp2, str_instnumb, str_winddir, meas_number_string);
            }

            fprintf(fh, "%i   %i   %6.0lf   %6.3lf   %6.3lf   %6.3lf   %6.1lf   %6.1lf   %6.1lf   %6.2lf   %6.3lf   %6.4lf   %6.4lf   %6.3lf   %6.4lf   %6.4lf\
   %6.3lf   %6.3lf   %6.8lf   %6.3lf   %6.4lf   %6.4lf   %6.3lf   %6.2lf   %6.2lf   %6.3lf   %6.2lf\
   %6.2lf   %6.3lf   %6.3lf   %6.4lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf\
   %6.3lf   %6.3lf   %6.1lf   %6.1lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %6.3lf   %i\n",
                    lda_ts_startnumber + lda_ts_index, data_count[0],
                    data_rate_mean,
                    model_scale*atof(x_position)/1000., model_scale*atof(y_position)/1000., model_scale*atof(z_position)/1000.,
                    atof(x_position), atof(y_position), atof(z_position), u_ref*lda_scale_factor,
                    DEFAULT_VALUE, data_raw_comp1_mean_arith/u_ref_sc, data_raw_comp2_mean_arith/u_ref_sc,
                    DEFAULT_VALUE, data_raw_comp1_rms_arith/u_ref_sc, data_raw_comp2_rms_arith/u_ref_sc,
                    DEFAULT_VALUE, DEFAULT_VALUE, data_raw_comp12_covar_arith/pow(u_ref_sc, 2.),
                    DEFAULT_VALUE, data_raw_comp1_mean_conf_arith/u_ref_sc, data_raw_comp2_mean_conf_arith/u_ref_sc,
                    DEFAULT_VALUE, data_raw_comp1_mean_arith, data_raw_comp2_mean_arith,
                    DEFAULT_VALUE, data_raw_comp1_rms_arith, data_raw_comp2_rms_arith,
                    DEFAULT_VALUE, DEFAULT_VALUE, data_raw_comp12_covar_arith,
                    DEFAULT_VALUE, data_raw_comp1_mean_conf_arith, data_raw_comp2_mean_conf_arith,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    data_raw_comp1_skew_arith, data_raw_comp1_flat_arith,
                    data_raw_comp2_skew_arith, data_raw_comp2_flat_arith,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, DEFAULT_VALUE,
                    DEFAULT_VALUE, quality_flag);
        }

        fclose(fh);
        
}










    
/******************************************************
* function    : lda_open_write_file_output_1          *
*-----------------------------------------------------*
* task        : open two files for ASCII-output:      *
*               two timeseries                        *
* parameter   : no one                                *
* return value: no one                                *
******************************************************/
void lda_open_write_file_output_1()
{
    sprintf(lda_ts_outputfile, "%s_%s_%s_%s_%s_%s_%s_%s_%s.tec.ts",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1, str_instnumb,
            str_winddir, meas_number_string, ts_string);
    fh = fopen(lda_ts_outputfile, "w");
    

    fprintf(fh, "main project    : %s\n", str_maincamp);
    fprintf(fh, "sub project     : %s\n", str_subcamp);
    if (strcmp(str_wt, BLASIUS) == 0) {
        fprintf(fh, "wind tunnel     : Blasius\n\n");
    }
    else if (strcmp(str_wt, WOTAN) == 0) {
        fprintf(fh, "wind tunnel     : Wotan\n\n");
    }
    fprintf(fh, "measurement             : flow measurement\n");
    fprintf(fh, "principle of measurement: laser doppler anemometry\n");
    fprintf(fh, "instrument              : %s\n\n", str_instnumb);
    if (strcmp(str_comp1, U_WIND) == 0 ||
                strcmp(str_comp1, V_WIND) == 0 ||
                strcmp(str_comp1, W_WIND) == 0) {
                    fprintf(fh, "wind component 1: %s\n", str_comp1);
                }
    if (strcmp(str_comp2, U_WIND) == 0 ||
                strcmp(str_comp2, V_WIND) == 0 ||
                strcmp(str_comp2, W_WIND) == 0) {
                    fprintf(fh, "wind component 2: %s\n", str_comp2);
                }
    fprintf(fh, "wind direction  : %s deg\n", str_winddir);
    if (strcmp(str_corr, CORRELATION) == 0) {
                fprintf(fh, "correlated measurement: yes\n");
            }
            else {
                fprintf(fh, "correlated measurement: no\n");
            }
    fprintf(fh, "number: %s\n\n", str_measnumb);           

            
    fprintf(fh, "%s\n%s\ndate: %s\nx-position: %s\ny-position: %s\n",
                header_identity, project_name, time_stamp, x_position, y_position);
    fprintf(fh, "z-position: %s\ntime step: %lf s\n", z_position, time_step_mean);
    fprintf(fh, "Uref = %lf m/s\n\n", u_ref);


    fprintf(fh, "statistic parameters of raw data (arithmetic averaging):\n");
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n",
                        str_comp1, data_raw_comp1_mean_arith, str_comp1, data_raw_comp1_rms_arith,
                        str_comp1, data_raw_comp1_skew_arith, str_comp1, data_raw_comp1_flat_arith);
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n\n",
                        str_comp2, data_raw_comp2_mean_arith, str_comp2, data_raw_comp2_rms_arith,
                        str_comp2, data_raw_comp2_skew_arith, str_comp2, data_raw_comp2_flat_arith);
    fprintf(fh, "statistic parameters of resampled data (arithmetic averaging):\n");
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n",
                        str_comp1, data_resam_comp1_mean_arith, str_comp1, data_resam_comp1_rms_arith,
                        str_comp1, data_resam_comp1_skew_arith, str_comp1, data_resam_comp1_flat_arith);
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n\n",
                        str_comp2, data_resam_comp2_mean_arith, str_comp2, data_resam_comp2_rms_arith,
                        str_comp2, data_resam_comp2_skew_arith, str_comp2, data_resam_comp2_flat_arith);
    fprintf(fh, "statistic parameters of raw data (with TT weighted averaging):\n");
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n",
                        str_comp1, data_raw_comp1_mean_weight, str_comp1, data_raw_comp1_rms_weight,
                        str_comp1, data_raw_comp1_skew_weight, str_comp1, data_raw_comp1_flat_weight);
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n\n",
                        str_comp2, data_raw_comp2_mean_weight, str_comp2, data_raw_comp2_rms_weight,
                        str_comp2, data_raw_comp2_skew_weight, str_comp2, data_raw_comp2_flat_weight);
    fprintf(fh, "statistic parameters of resampled data (with TT weighted averaging):\n");
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n",
                        str_comp1, data_resam_comp1_mean_weight, str_comp1, data_resam_comp1_rms_weight,
                        str_comp1, data_resam_comp1_skew_weight, str_comp1, data_resam_comp1_flat_weight);
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n\n",
                        str_comp2, data_resam_comp2_mean_weight, str_comp2, data_resam_comp2_rms_weight,
                        str_comp2, data_resam_comp2_skew_weight, str_comp2, data_resam_comp2_flat_weight);

    
    fprintf(fh, "\"i[-]\" \"t[s]\" \"%s[m/s]\" \"%s[-]\"\n", str_comp1, str_comp1);  
      
    i = 0;
    
    do {
        fprintf(fh, "%i   %lf   %5.3lf   %5.3lf\n", i, data_resam[0][i], data_resam[2][i], (data_resam[2][i]/u_ref)/lda_scale_factor);
        i++;
    } while(i < data_count_resam);
    fclose(fh);



    
    sprintf(lda_ts_outputfile, "%s_%s_%s_%s_%s_%s_%s_%s_%i.tec.ts",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp2, str_instnumb,
            str_winddir, str_measnumb, lda_ts_startnumber + lda_ts_index);
    fh = fopen(lda_ts_outputfile, "w");
    

    fprintf(fh, "main project    : %s\n", str_maincamp);
    fprintf(fh, "sub project     : %s\n", str_subcamp);
    if (strcmp(str_wt, BLASIUS) == 0) {
        fprintf(fh, "wind tunnel     : Blasius\n\n");
    }
    else if (strcmp(str_wt, WOTAN) == 0) {
        fprintf(fh, "wind tunnel     : Wotan\n\n");
    }
    fprintf(fh, "measurement             : flow measurement\n");
    fprintf(fh, "principle of measurement: laser doppler anemometry\n");
    fprintf(fh, "instrument              : %s\n\n", str_instnumb);
    if (strcmp(str_comp1, U_WIND) == 0 ||
                strcmp(str_comp1, V_WIND) == 0 ||
                strcmp(str_comp1, W_WIND) == 0) {
                    fprintf(fh, "wind component 1: %s\n", str_comp1);
                }
    if (strcmp(str_comp2, U_WIND) == 0 ||
                strcmp(str_comp2, V_WIND) == 0 ||
                strcmp(str_comp2, W_WIND) == 0) {
                    fprintf(fh, "wind component 2: %s\n", str_comp2);
                }
    fprintf(fh, "wind direction  : %s deg\n", str_winddir);
    if (strcmp(str_corr, CORRELATION) == 0) {
                fprintf(fh, "correlated measurement: yes\n");
            }
            else {
                fprintf(fh, "correlated measurement: no\n\n");
            }
    fprintf(fh, "number: %s\n\n", str_measnumb);
    

    fprintf(fh, "%s\n%s\ndate: %s\nx-position: %s\ny-position: %s\n",
                header_identity, project_name, time_stamp, x_position, y_position);
    fprintf(fh, "z-position: %s\ntime step: %lf s\n", z_position, time_step_mean);
    fprintf(fh, "Uref = %lf m/s\n\n", u_ref);       
                      

    fprintf(fh, "statistic parameters of raw data (arithmetic averaging):\n");
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n",
                        str_comp1, data_raw_comp1_mean_arith, str_comp1, data_raw_comp1_rms_arith,
                        str_comp1, data_raw_comp1_skew_arith, str_comp1, data_raw_comp1_flat_arith);
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n\n",
                        str_comp2, data_raw_comp2_mean_arith, str_comp2, data_raw_comp2_rms_arith,
                        str_comp2, data_raw_comp2_skew_arith, str_comp2, data_raw_comp2_flat_arith);
    fprintf(fh, "statistic parameters of resampled data (arithmetic averaging):\n");
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n",
                        str_comp1, data_resam_comp1_mean_arith, str_comp1, data_resam_comp1_rms_arith,
                        str_comp1, data_resam_comp1_skew_arith, str_comp1, data_resam_comp1_flat_arith);
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n\n",
                        str_comp2, data_resam_comp2_mean_arith, str_comp2, data_resam_comp2_rms_arith,
                        str_comp2, data_resam_comp2_skew_arith, str_comp2, data_resam_comp2_flat_arith);
    fprintf(fh, "statistic parameters of raw data (with TT weighted averaging):\n");
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n",
                        str_comp1, data_raw_comp1_mean_weight, str_comp1, data_raw_comp1_rms_weight,
                        str_comp1, data_raw_comp1_skew_weight, str_comp1, data_raw_comp1_flat_weight);
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n\n",
                        str_comp2, data_raw_comp2_mean_weight, str_comp2, data_raw_comp2_rms_weight,
                        str_comp2, data_raw_comp2_skew_weight, str_comp2, data_raw_comp2_flat_weight);
    fprintf(fh, "statistic parameters of resampled data (with TT weighted averaging):\n");
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n",
                        str_comp1, data_resam_comp1_mean_weight, str_comp1, data_resam_comp1_rms_weight,
                        str_comp1, data_resam_comp1_skew_weight, str_comp1, data_resam_comp1_flat_weight);
            fprintf(fh, "%smean: %lf m/s\n%srms: %lf m/s\n%sskew: %lf\n%sflat: %lf\n\n",
                        str_comp2, data_resam_comp2_mean_weight, str_comp2, data_resam_comp2_rms_weight,
                        str_comp2, data_resam_comp2_skew_weight, str_comp2, data_resam_comp2_flat_weight);


    fprintf(fh, "\"i[-]\" \"t[s]\" \"%s[m/s]\" \"%s[-]\"\n", str_comp2, str_comp2);
                  
    i = 0;
    
    do {
        fprintf(fh, "%i   %lf   %5.3lf   %5.3lf\n", i, data_resam[0][i], data_resam[3][i], (data_resam[3][i]/u_ref)/lda_scale_factor);
        i++;
    } while(i < data_count_resam);

    
    fclose(fh);
    
}





/******************************************************
* function    : lda_open_write_file_output_mean_devel *
*-----------------------------------------------------*
* task        : open two files for ASCII-output:      *
*               two timeseries                        *
* parameter   : no one                                *
* return value: no one                                *
******************************************************/
void lda_open_write_file_output_mean_devel()
{
    sprintf(out_file_mean_devel, "%s_%s_%s_%s_%s%s_%s%s_%s_%s_%s_mean_devel.txt",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1,
            str_comp2, str_instnumb, str_corr, str_winddir,
            meas_number_string, ts_string);
    fh = fopen(out_file_mean_devel, "w");

    fprintf(fh, "VARIABLES= \"j[-]\" \"%smean_raw[m/s]\" \"%smean_raw[m/s]\" \"%smean_resam[m/s]\" \"%smean_resam[m/s]\"\n", str_comp1, str_comp2, str_comp1, str_comp2);

    j = 0;
    k = 1;

    mean_devel1 = 0.;
    mean_devel2 = 0.;
    mean_devel3 = 0.;
    mean_devel4 = 0.;

    do {
         mean_devel1 = (mean_devel1*(k-1) + data_raw[2][j])/k;
         mean_devel2 = (mean_devel2*(k-1) + data_raw[3][j])/k;
         mean_devel3 = (mean_devel3*(k-1) + data_resam[2][j])/k;
         mean_devel4 = (mean_devel4*(k-1) + data_resam[3][j])/k;

         fprintf(fh, "%i     %4.3lf     %4.3lf     %4.3lf     %4.3lf\n",
                    j, mean_devel1, mean_devel2, mean_devel3, mean_devel4);
                     
         j++;
         k++;
                   
    } while(j < data_count_resam);

    fclose(fh);
}                  

    






/********************************************************
* function    : lda_open_write_file_output_stat         *
*-------------------------------------------------------*
* task        : open one file for ASCII-output:         *
*               statistic file for couple of timeseries *
* parameter   : no one                                  *
* return value: no one                                  *
********************************************************/   
void lda_open_write_file_output_stat()
{
    sprintf(out_file_stat_raw, "%s_%s_%s_%s_%s%s_%s%s_%s_%s_stat_raw.txt",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1,
            str_comp2, str_instnumb, str_corr, str_winddir,
            meas_number_string);
    fh = fopen(out_file_stat_raw, "a");
    
    if(lda_ts_index == 0){
    fprintf(fh, "Name of timeseries                            Date                       X [m]   Y [m]   Z [m]     \
Count [#]   Datarate [#/s]   U_ref [m/s]          \
%s_mean [m/s]   %s_mean [m/s]   %sx%s [m^2/s^2]   %s_rms [m/s]   %s_rms [m/s]   %smean_conf [m/s]   %smean_conf [m/s]   \
%s_Iturb[%]    %s_Iturb[%]    %s_skew    %s_skew    %s_flat   %s_flat          \
%s_mean [m/s]   %s_mean [m/s]   %sx%s [m^2/s^2]   %s_rms [m/s]   %s_rms [m/s]   %smean_conf [m/s]   %smean_conf [m/s]   \
%s_Iturb[%]    %s_Iturb[%]    %s_skew    %s_skew    %s_flat   %s_flat          \
LUx[m]\n",
str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2,
str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2);
    }
        
    fprintf(fh, "%s   %s     %4.3lf   %4.3lf   %4.3lf     %i   %4.2lf   %4.3lf          \
%4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf          \
%4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf          \
%4.3lf\n",
                lda_ts_inputfile, time_stamp, atof(x_position)/1000., atof(y_position)/1000.,
                atof(z_position)/1000., data_count[0], data_rate_mean, u_ref,
                data_raw_comp1_mean_arith, data_raw_comp2_mean_arith, data_raw_comp12_covar_arith,
                data_raw_comp1_rms_arith, data_raw_comp2_rms_arith, data_raw_comp1_mean_conf_arith,
                data_raw_comp2_mean_conf_arith, data_raw_comp1_turb_arith, data_raw_comp2_turb_arith,
                data_raw_comp1_skew_arith, data_raw_comp2_skew_arith, data_raw_comp1_flat_arith,
                data_raw_comp2_flat_arith,
                data_resam_comp1_mean_arith, data_resam_comp2_mean_arith, data_resam_comp12_covar_arith,
                data_resam_comp1_rms_arith, data_resam_comp2_rms_arith, data_resam_comp1_mean_conf_arith,
                data_resam_comp2_mean_conf_arith, data_resam_comp1_turb_arith, data_resam_comp2_turb_arith,
                data_resam_comp1_skew_arith, data_resam_comp2_skew_arith, data_resam_comp1_flat_arith,
                data_resam_comp2_flat_arith,
                l_ux);
                              
    fclose(fh);
}






/********************************************************
* function    : lda_open_write_file_output_stat_resamp  *
*-------------------------------------------------------*
* task        : open one file for ASCII-output:         *
*               statistic file for couple of timeseries *
* parameter   : no one                                  *
* return value: no one                                  *
********************************************************/   
void lda_open_write_file_output_stat_resamp()
{
    sprintf(out_file_stat_resamp, "%s_%s_%s_%s_%s%s_%s%s_%s_%s_stat_resamp.txt",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1,
            str_comp2, str_instnumb, str_corr, str_winddir,
            meas_number_string);
    fh = fopen(out_file_stat_resamp, "a");
    
    if(lda_ts_index == 0){
    fprintf(fh, "Name of timeseries                            Date                       X [m]   Y [m]   Z [m]     \
Datarate [#/ms]   U_ref [m/s]   %s_mean [m/s]   %s_mean [m/s]   %sx%s [m^2/s^2]   %s_rms [m/s]    %s_rms [m/s]   %smean_conf [m/s]   %smean_conf [m/s]    \
%s_Iturb[%]    %s_Iturb[%]    %s_skew    %s_skew    %s_flat   %s_flat   LUx[m]\n", str_comp1, str_comp2, str_comp1,
str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2);
    }
        
    fprintf(fh, "%s   %s   %4.3lf   %4.3lf   %4.3lf   %4.2lf     %4.3lf       %4.3lf     %4.3lf     %4.3lf     %4.3lf     %4.3lf     \
%4.3lf     %4.3lf     %4.3lf     %4.3lf     %4.3lf     %4.3lf     %4.3lf     %4.3lf     %4.3lf\n",
                lda_ts_inputfile, time_stamp, atof(x_position)/1000., atof(y_position)/1000.,
                atof(z_position)/1000., data_rate_mean, u_ref, data_resam_comp1_mean_arith, data_resam_comp2_mean_arith,
                data_resam_comp12_covar_arith,
                data_resam_comp1_rms_arith, data_resam_comp2_rms_arith, data_resam_comp1_mean_conf_arith,
                data_resam_comp2_mean_conf_arith, data_resam_comp1_turb_arith, data_resam_comp2_turb_arith,
                data_resam_comp1_skew_arith, data_resam_comp2_skew_arith, data_resam_comp1_flat_arith,
                data_resam_comp2_flat_arith, l_ux);
                              
    fclose(fh);
}







/***********************************************************
* function    : lda_open_write_file_output_tecplot_raw     *
*----------------------------------------------------------*
* task        : open one file for ASCII-output:            *
*               tecplot file for couple of timeseries      *
* parameter   : no one                                     *
* return value: no one                                     *
***********************************************************/   
void lda_open_write_file_output_tecplot_raw()
{
    sprintf(out_file_tecplot_raw, "%s_%s_%s_%s_%s%s_%s%s_%s_%s_tecplot_raw.tec.ts",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1,
            str_comp2, str_instnumb, str_corr, str_winddir,
            meas_number_string);
    fh = fopen(out_file_tecplot_raw, "a");

    if(lda_ts_index == 0){
    fprintf(fh, "VARIABLES= \"X [m]\"   \"Y [m]\"   \"Z [m]\"   \"Zfs [m]\"   \"Datarate [#/ms]\"          \"%s[-]\"   \"%s[-]\"   \"%sx%s/Uref^2 [-]\"   \"%s_Iturb[%]\"   \"%s_Iturb[%]\"   \"LUx[m]\"\n",
                str_comp1, str_comp2, str_comp1, str_comp2, str_comp1, str_comp2);
    }

    fprintf(fh, "%4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.2lf     %4.3lf       %4.3lf     %4.3lf     %4.3lf     %4.3lf     %4.3lf\n",
                atof(x_position)/1000., atof(y_position)/1000., atof(z_position)/1000., (atof(z_position)/1000.)*1000.,
                (atof(z_position)/1000.)*800., (atof(z_position)/1000.)*500., (atof(z_position)/1000.)*400., (atof(z_position)/1000.)*300., 
                data_rate_mean, (data_raw_comp1_mean_arith/u_ref)/lda_scale_factor, (data_raw_comp2_mean_arith/u_ref)/lda_scale_factor, data_raw_comp12_covar_arith, data_raw_comp1_turb_arith,
                data_raw_comp2_turb_arith, l_ux);
                              
    fclose(fh);
}    






    
/***********************************************************
* function    : lda_open_write_file_output_tecplot_resamp  *
*----------------------------------------------------------*
* task        : open one file for ASCII-output:            *
*               tecplot file for couple of timeseries      *
* parameter   : no one                                     *
* return value: no one                                     *
***********************************************************/   
void lda_open_write_file_output_tecplot_resamp()
{
    sprintf(out_file_tecplot_resamp, "%s_%s_%s_%s_%s%s_%s%s_%s_%s_tecplot_resamp.tec.ts",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1,
            str_comp2, str_instnumb, str_corr, str_winddir,
            meas_number_string);
    fh = fopen(out_file_tecplot_resamp, "a");

    if(lda_ts_index == 0){
    fprintf(fh, "VARIABLES= \"X [m]\"   \"Y [m]\"   \"Z [m]\"   \"Zfs1000 [m]\"   \"Zfs800 [m]\"   \"Zfs500 [m]\"   \"Zfs400 [m]\"   \"Zfs300 [m]\"     \
\"Datarate [#/ms]\"   \"%s[-]\"   \"%s[-]\"   \"%sx%s/Uref^2 [-]\"   \"%s_Iturb[%]\"   \"%s_Iturb[%]\"   \"LUx[m]\"\n", str_comp1, str_comp2, str_comp1, str_comp2,
                                                                                                str_comp1, str_comp2);
    }

    fprintf(fh, "%4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.3lf   %4.2lf     %4.3lf       %4.3lf     %4.3lf     %4.3lf     %4.3lf     %4.3lf\n",
                atof(x_position)/1000., atof(y_position)/1000., atof(z_position)/1000., (atof(z_position)/1000.)*1000.,
                (atof(z_position)/1000.)*800., (atof(z_position)/1000.)*500., (atof(z_position)/1000.)*400., (atof(z_position)/1000.)*300.,
                data_rate_mean, (data_resam_comp1_mean_arith/u_ref)/lda_scale_factor, (data_resam_comp2_mean_arith/u_ref)/lda_scale_factor, data_resam_comp12_covar_arith, data_resam_comp1_turb_arith,
                data_resam_comp2_turb_arith, l_ux);
                              
    fclose(fh);
}







/***********************************************************
* function    : lda_open_write_file_output_profit_raw      *
*----------------------------------------------------------*
* task        : open one file for ASCII-output:            *
*               profit file for couple of timeseries       *
* parameter   : no one                                     *
* return value: no one                                     *
***********************************************************/   
void lda_open_write_file_output_profit_raw()
{
    sprintf(out_file_profit_raw, "%s_%s_%s_%s_%s%s_%s%s_%s_%s_profit_raw.txt",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1,
            str_comp2, str_instnumb, str_corr, str_winddir,
            meas_number_string);
    fh = fopen(out_file_profit_raw, "a");

    fprintf(fh, "%4.3lf   %4.3lf\n", atof(z_position)/1000., data_raw_comp1_mean_arith);
                              
    fclose(fh);
}






/***********************************************************
* function    : lda_open_write_file_output_profit_resamp   *
*----------------------------------------------------------*
* task        : open one file for ASCII-output:            *
*               profit file for couple of timeseries       *
* parameter   : no one                                     *
* return value: no one                                     *
***********************************************************/   
void lda_open_write_file_output_profit_resamp()
{
    sprintf(out_file_profit_resamp, "%s_%s_%s_%s_%s%s_%s%s_%s_%s_profit_resamp.txt",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1,
            str_comp2, str_instnumb, str_corr, str_winddir,
            meas_number_string);
    fh = fopen(out_file_profit_resamp, "a");

    fprintf(fh, "%4.3lf   %4.3lf\n", atof(z_position)/1000., data_resam_comp1_mean_arith);
                              
    fclose(fh);
}    





/***********************************************************
* function    : lda_open_write_file_output_autocorrelation *
*----------------------------------------------------------*
* task        : open one file for ASCII-output:            *
*               autocorrelation                            *
* parameter   : no one                                     *
* return value: no one                                     *
***********************************************************/   
void lda_open_write_file_output_autocorrelation(int lag_step)
{
    sprintf(out_file_autocorr, "AUTOCORR\\%s_%s_%s_%s_%s%s_%s%s_%s_%s_%s_autocorr.tec.ts",
            str_maincamp, str_subcamp, str_wt, str_meastype,
            str_comp1, str_comp2, str_instnumb, str_corr, str_winddir,
            meas_number_string, ts_string);
    fh = fopen(out_file_autocorr, "a");

    if(i == 0){   
        fprintf(fh, "Variables = \"k\" \"time[s]\" \"R%s%s\"\n", str_comp1, str_comp1);
    }    

    if(RAA[j] >= 0.001) {
        fprintf(fh, "%i      %5.4lf    %5.8lf\n", j, j*time_step_mean, RAA[j]);
    }

    fclose(fh);
}
















/*****************************************************************
* function    : lda_output_post_processed_timeseries (resampled) *
*----------------------------------------------------------------*
* task        : open one file for ASCII-output:                  *
*               one timeseries                                   *
* parameter   : no one                                           *
* return value: no one                                           *
*****************************************************************/
void lda_open_write_file_output_ts_resamp()
{
    
    sprintf(lda_ts_resamp_outputfile, "TS_resamp\\%s_%s_%s_%s_%s%s_%s_%s_%s_%s_resamp_EWTL.ts",
            str_maincamp, str_subcamp, str_wt, str_meastype, str_comp1, str_comp2, str_instnumb,
            str_winddir, meas_number_string, ts_string);
    fh = fopen(lda_ts_resamp_outputfile, "w");
    


    if (strcmp(str_comp1, U_WIND) == 0 && strcmp(str_comp2, W_WIND) == 0) {
        
        fprintf(fh, "VARIABLES= \"i [-]\" \"AT [ms]\" \"U [m/s]\" \"W [m/s]\"\n");  
      
 
        i = 0;
    
        do {    

            fprintf(fh, "%i      %5.3lf      %5.3lf    %5.3lf\n", i, data_resam[0][i]*1000., data_resam[2][i], data_resam[3][i]);
            i++;
        } while(i < data_count[0]);
    }
    

    
    if (strcmp(str_comp1, U_WIND) == 0 && strcmp(str_comp2, V_WIND) == 0) {
        
        fprintf(fh, "VARIABLES= \"i [-]\" \"AT [ms]\" \"U [m/s]\" \"V [m/s]\"\n");  
        
 
        i = 0;
    
        do {    

            fprintf(fh, "%i      %5.3lf      %5.3lf    %5.3lf\n", i, data_resam[0][i]*1000., data_resam[2][i], data_resam[3][i]);
            i++;
        } while(i < data_count[0]);
    }
    


    if (strcmp(str_comp1, V_WIND) == 0 && strcmp(str_comp2, W_WIND) == 0) {
        
        fprintf(fh, "VARIABLES= \"i [-]\" \"AT [ms]\" \"V [m/s]\" \"W [m/s]\"\n");  
      
 
        i = 0;
    
        do {    

            fprintf(fh, "%i      %5.3lf      %5.3lf    %5.3lf\n", i, data_resam[0][i]*1000., data_resam[2][i], data_resam[3][i]);
            i++;
        } while(i < data_count[0]);
    }
    

    fclose(fh);
}









